import type { Player } from "@prisma/client"
import bcrypt from "bcrypt"
import prisma from "../../prisma"
import logging from "../logging"

async function createPlayerDB(
  payload:
    | {
        username: string
        password: string
      }
    | "anonymous",
  next: (player: Player) => void
) {
  let player: Player
  if (payload === "anonymous") {
    player = await prisma.player.create({ data: {} })
    logging("Anonymous player created: " + player.id, ["debug"])
  } else {
    const { username, password } = payload
    player = await prisma.player.create({
      data: {
        username,
        passwordHash: await bcrypt.hash(password, 10),
        anonymous: false,
      },
    })
    logging("Player registered: " + player.id, ["debug"])
  }

  return next(player)
}

export default createPlayerDB
